/*
 * Copyright (C) 2012 SIC! Software GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#define LOG_NDEBUG 1//0 = enable logging in NON-Debug build
#define LOG_TAG "VCNL4020_LIGHT"
#define FUNC_LOG LOGV("%s", __PRETTY_FUNCTION__)

#include <fcntl.h>
#include <errno.h>
#include <math.h>
#include <poll.h>
#include <unistd.h>
#include <dirent.h>
#include <sys/select.h>
#include <cutils/log.h>
#include <pthread.h>

#include "LightSensor.h"

//-----------------------------------------------------------------------------
LightSensor::LightSensor()
    :SensorBase("light_sensor")
    ,mPreviousLight(-1.0)
{
    FUNC_LOG;
    ipszSensorEnableRelativeName="vcnl4020/lux_enable";//no ownership
    ipszSensorSetDelayRelativeFileName="vcnl4020/lux_delay";//no ownership
}


//-----------------------------------------------------------------------------
//virtual from SensorBase
//@rturn number of events read 0 if no event is available
int LightSensor::poll(sensors_event_t* apData, int count){
    FUNC_LOG;

    input_event event;
    const ssize_t nRead=read(mInputEventFd,&event,sizeof(event));
    if(nRead<(ssize_t)sizeof(input_event)){
        return 0;
    }
    if(!event.code){
        return 0;
    }
    if(event.value&0xffff0000){//invalid values are ignored (this is needed to get correct value after sensor enable)
        return 0;
    }
    if(mPreviousLight == event.value && mFirstEventAfterEnableWasSent){
        return 0;
    }
    if(!mEnabled){
        return 0;
    }
    mPreviousLight = event.value;
    mFirstEventAfterEnableWasSent=true;

    sensors_event_t &rEvent=*apData;
    memset(&rEvent, 0, sizeof(rEvent));
    rEvent.version = sizeof(sensors_event_t);//must be sizeof(struct sensors_event_t)
    rEvent.sensor = ID_L;
    rEvent.type = SENSOR_TYPE_LIGHT;

    rEvent.light = mPreviousLight;
    //convert to Lux
    rEvent.light *=0.25;

    rEvent.timestamp = mLastPollTime = getTimestamp();
    return 1;
}

//#############################################################################
//eof Lightsensor.cpp

