/*
 * Copyright (C) 2012 SIC! Software GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#define LOG_NDEBUG 1//0 = enable logging in NON-Debug build
#define LOG_TAG "VCNL4020_PROXIMITY"
#define FUNC_LOG LOGV("%s", __PRETTY_FUNCTION__)

#include <fcntl.h>
#include <errno.h>
#include <math.h>
#include <poll.h>
#include <unistd.h>
#include <dirent.h>
#include <sys/select.h>
#include <cutils/log.h>
#include <pthread.h>

#include "ProximitySensor.h"

//-----------------------------------------------------------------------------
ProximitySensor::ProximitySensor()
    :SensorBase("proximity_sensor")
    ,mPreviousDistance(-1.0)
{
    FUNC_LOG;
    ipszSensorEnableRelativeName="vcnl4020/prox_enable";//no ownership
    ipszSensorSetDelayRelativeFileName="vcnl4020/prox_delay";//no ownership
}


//-----------------------------------------------------------------------------
//virtual from SensorBase
//@rturn number of events read 0 if no event is available
int ProximitySensor::poll(sensors_event_t* apData, int count){
    FUNC_LOG;

    input_event event;
    const ssize_t nRead=read(mInputEventFd,&event,sizeof(event));
    if(nRead<(ssize_t)sizeof(input_event)){
        return 0;
    }
    if(!event.code){
        return 0;
    }
    if(event.value&0xffff0000){//invalid values are ignored (this is needed to get correct value after sensor enable)
        return 0;
    }
    if(mPreviousDistance == event.value && mFirstEventAfterEnableWasSent){
        return 0;
    }
    if(!mEnabled){
        return 0;
    }
    mPreviousDistance = event.value;
    mFirstEventAfterEnableWasSent=true;

    sensors_event_t &rEvent=*apData;
    memset(&rEvent, 0, sizeof(rEvent));
    rEvent.version = sizeof(sensors_event_t);//must be sizeof(struct sensors_event_t)
    rEvent.sensor = ID_P;
    rEvent.type = SENSOR_TYPE_PROXIMITY;
/*
* The distance value is measured in centimeters.  Note that some proximity
* sensors only support a binary "close" or "far" measurement.  In this case,
* the sensor should report its maxRange value in the "far" state and a value
* less than maxRange in the "near" state.
* - this logig is done in the kernel module
*/
    rEvent.distance = mPreviousDistance;
    rEvent.timestamp = mLastPollTime = getTimestamp();
    return 1;
}

//#############################################################################
//eof ProximitySensor.cpp

