/*
 * Copyright (C) 2012 SIC! Software GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef SENSORBASE_H
#define SENSORBASE_H

#include <stdint.h>
#include <errno.h>
#include <sys/cdefs.h>
#include <sys/types.h>

#include "sensors.h"

/*****************************************************************************/

class SensorBase {
public:
    SensorBase(const char* apszInputSensorName);
    virtual ~SensorBase();
    static int64_t getTimestamp();
    virtual int getPollFd() const{return mInputEventFd;}
    //called from Android system via c func ptr in sensors_poll_device_t (c -> c++ wrapper is in sensors.cpp)
    virtual int activate(bool en);
    virtual int setDelay(int64_t ns);
    virtual int poll(sensors_event_t *data, int count);
protected:
    int64_t getRemainingPollDelay()const;
    int openSysFsFile(const char* apszDeviceRelativeName)const;
private:
    int openInput(const char* apszInputSensorName);
protected://data
    bool mEnabled;
    bool mFirstEventAfterEnableWasSent;
    pthread_mutex_t mLock;
    int mInputEventFd;
    int64_t mDelay;
    int64_t mLastPollTime;
    char *ipszInputEventName;//has ownership ->see open input
    const char * ipszSensorEnableRelativeName;//no ownership
    const char * ipszSensorSetDelayRelativeFileName;//no ownership
};
#endif //SENSORBASE_H

