/**
 * www.sic-software.com
 * @file AbstractSensorActivity.java
 * @date 21.06.2012
 * @author fl
 * @brief See Javadoc for this class
 */
package com.sic.vishay.vcnl40x0.demo;

import android.app.Activity;
import android.hardware.Sensor;
import android.hardware.SensorEvent;
import android.hardware.SensorEventListener;
import android.hardware.SensorManager;
import android.os.Bundle;
import android.view.View;
import android.widget.TextView;
import android.widget.ToggleButton;

/**
 * Abstract base Activity, that handle access to the sensors.
 */
public abstract class AbstractSensorActivity extends Activity implements SensorEventListener {
	protected TextView mSensorTypeTextView;
	protected TextView mSensorNameTextView;
	protected TextView mSensorVendorTextView;
	protected TextView mSensorVersionTextView;
	protected TextView mSensorValueTextView;
	protected TextView mSensorMaxRangeTextView;
	protected TextView mSensorMinDelayTextView;
	protected TextView mSensorPowerTextView;
	protected TextView mSensorResolutionTextView;
	
	protected SensorManager mSensorManager;
	protected Sensor mSensor;
	
	protected ToggleButton btn_toggle_sensor;
	protected boolean sensorIsEnabled = true;
	
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.sensor);
        
        mSensorTypeTextView = (TextView)findViewById(R.id.sensorType);
        mSensorNameTextView = (TextView)findViewById(R.id.sensorName);
        mSensorVendorTextView = (TextView)findViewById(R.id.sensorVendor);
        mSensorValueTextView = (TextView)findViewById(R.id.sensorValue);
        mSensorVersionTextView = (TextView)findViewById(R.id.sensorVersion);
        mSensorMaxRangeTextView = (TextView)findViewById(R.id.sensorMaxRange);
        mSensorMinDelayTextView = (TextView)findViewById(R.id.sensorMinDelay);
        mSensorPowerTextView = (TextView)findViewById(R.id.sensorPower);
        mSensorResolutionTextView = (TextView)findViewById(R.id.sensorResolution);
        
        mSensorManager = (SensorManager)getSystemService(SENSOR_SERVICE);
    }
    
    @Override
    protected void onStart() {
    	super.onStart();
    	
    	if (mSensor != null) {
    		mSensorVendorTextView.setText(mSensor.getVendor());
    		mSensorNameTextView.setText(mSensor.getName());
    		mSensorVersionTextView.setText("" + mSensor.getVersion());
    		mSensorValueTextView.setText("-");
    		mSensorMaxRangeTextView.setText("" + mSensor.getMaximumRange());
    		mSensorMinDelayTextView.setText("" + mSensor.getMinDelay());
    		mSensorPowerTextView.setText("" + mSensor.getPower());
    		mSensorResolutionTextView.setText(""+ mSensor.getResolution());
    		
    		mSensorManager.registerListener(this, mSensor, SensorManager.SENSOR_DELAY_NORMAL);
    	} else {
    		mSensorVendorTextView.setText("No sensor found");
    		mSensorNameTextView.setText("No sensor found");
    		mSensorVersionTextView.setText("No sensor found");
    		mSensorValueTextView.setText("No sensor found");
    	}
    	
    }
    
    @Override
    protected void onStop() {
    	super.onStop();
    	mSensorManager.unregisterListener(this);
    }

	@Override
	public void onAccuracyChanged(Sensor sensor, int accuracy) {
		
	}
	
	public void toggleSensor(View view){
		if(mSensor != null){
			if(sensorIsEnabled){
				mSensorManager.unregisterListener(this);
				sensorIsEnabled = false;
			}else{
				mSensorManager.registerListener(this, mSensor, SensorManager.SENSOR_DELAY_NORMAL);
				sensorIsEnabled = true;
			}
		}
	}

	@Override
	public void onSensorChanged(SensorEvent event) {
		String valueString = "";
		
		for (float value : event.values) {
			valueString += "" + value + ", ";
		}
		
		if (valueString.length() > 2) {
			valueString = valueString.substring(0, valueString.length()-2);
		}
		
		mSensorValueTextView.setText(valueString);
	}
	
}
